# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import pages.utils.image
import django.utils.timezone
import imagekit.models.fields


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Page',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('seo_title', models.CharField(max_length=100)),
                ('seo_sub_title', models.CharField(max_length=100)),
                ('seo_desc', models.CharField(max_length=100)),
                ('seo_keywords', models.CharField(max_length=100)),
                ('created', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
                ('modified', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
                ('is_active', models.BooleanField(default=False)),
                ('title', models.CharField(max_length=100)),
                ('slug', models.SlugField(max_length=150)),
                ('external_url', models.URLField(max_length=500, verbose_name=b'External URL', blank=True)),
            ],
            options={
                'db_table': 'pages',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Slider',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
                ('modified', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
                ('title', models.CharField(max_length=200)),
                ('is_active', models.BooleanField(default=False)),
                ('dots', models.BooleanField(default=False)),
                ('speed', models.IntegerField(default=500)),
                ('page', models.ForeignKey(to='pages.Page')),
            ],
            options={
                'db_table': 'sliders',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='SliderContent',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('content', models.TextField()),
                ('config', models.TextField()),
                ('order', models.SmallIntegerField(default=1)),
            ],
            options={
                'db_table': 'slider_contents',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='SliderContentType',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=100)),
            ],
            options={
                'db_table': 'slider_content_types',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='SliderItem',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
                ('modified', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
                ('is_active', models.BooleanField(default=False)),
                ('picture_pc', imagekit.models.fields.ProcessedImageField(upload_to=pages.utils.image.upload_picture_to)),
                ('picture_tablet', imagekit.models.fields.ProcessedImageField(null=True, upload_to=pages.utils.image.upload_picture_to)),
                ('picture_mobile', imagekit.models.fields.ProcessedImageField(null=True, upload_to=pages.utils.image.upload_picture_to)),
                ('active_from', models.DateTimeField()),
                ('active_to', models.DateTimeField()),
                ('order', models.SmallIntegerField(default=1)),
                ('slider', models.ForeignKey(to='pages.Slider')),
            ],
            options={
                'db_table': 'slider_items',
            },
            bases=(models.Model,),
        ),
        migrations.AlterUniqueTogether(
            name='slideritem',
            unique_together=set([('order', 'slider')]),
        ),
        migrations.AddField(
            model_name='slidercontent',
            name='slider_item',
            field=models.ForeignKey(to='pages.SliderItem'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='slidercontent',
            name='type_content',
            field=models.ForeignKey(to='pages.SliderContentType'),
            preserve_default=True,
        ),
        migrations.AlterUniqueTogether(
            name='slidercontent',
            unique_together=set([('order', 'slider_item')]),
        ),
    ]



# -*- coding: utf-8 -*-
from django.shortcuts import redirect
from pages.models.page import Page


class PageRouteMiddleware(object):

    def process_view(self, request, view_func, view_args, view_kwargs):
        pass
        url = request.META['PATH_INFO']

        pages = Page.objects.filter()
        if pages.exists():
            pass
        else:
            pass
        return redirect(url)


# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import pages.utils.image
import imagekit.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0011_auto_20170616_0214'),
    ]

    operations = [
        migrations.RenameField(
            model_name='pageseo',
            old_name='url',
            new_name='slug',
        ),
        migrations.RemoveField(
            model_name='page',
            name='banner_share',
        ),
        migrations.RemoveField(
            model_name='pageseo',
            name='share_image',
        ),
        migrations.AddField(
            model_name='pageseo',
            name='banner_share',
            field=imagekit.models.fields.ProcessedImageField(null=True, upload_to=pages.utils.image.upload_picture_to, blank=True),
            preserve_default=True,
        ),
    ]



from django.contrib import admin
from django.db.models.loading import get_model

from pages.utils import constants


class ProductInline(admin.TabularInline):
    extra = 1


def get_page_inline_form():
    products = constants.PAGE_PRODUCTS
    for product in products:
        model = get_model(product[0], product[1])
    return ProductInline


# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.utils import timezone
from django.test import TestCase

from pages.schema import schema
from pages.models.page import Page
from pages.models.slider import Slider, SliderItem, SliderContent, SliderContentType


class SliderTestCase(TestCase):

    def setUp(self):
        self._create_data()

    def _create_page(self):
        page = Page()
        page.title = 'Test Page'
        page.external_url = 'https://www.crehana.com/'
        page.is_active = True
        page.save()
        return page

    def _create_slider(self, page):
        slider = Slider()
        slider.page = page
        slider.title = 'Test Page'
        slider.is_active = True
        slider.save()
        return slider

    def _create_item_slider(self, slider):
        slider_item = SliderItem()
        slider_item.slider = slider
        slider_item.active_from = timezone.now()
        slider_item.active_to = timezone.now()
        slider_item.save()
        return slider_item

    def _create_item_slider_content(self, slider_item):
        type_content = SliderContentType.objects.all()[0]
        slider_content = SliderContent()
        slider_content.slider_item = slider_item
        slider_content.type_content = type_content
        slider_content.active_from = timezone.now()
        slider_content.active_to = timezone.now()
        slider_content.config = '{"font-size": "medium", "text-align": "center"}'
        slider_content.save()

    def _create_data(self):
        page = self._create_page()
        slider = self._create_slider(page)
        slider_item = self._create_item_slider(slider)
        self._create_item_slider_content(slider_item)

    def get_sliders_query(self):
        query = '''
                    {
                       sliders {
                         title
                         is_active
                         dots
                         speed
                         items {
                            absolute_url_picture_pc
                            absolute_url_picture_tablet
                            absolute_url_picture_mobile
                            active_from
                            active_to
                            order
                            contents {
                                content
                                config
                                order
                                type_content {
                                    name
                                }
                            }
                         }
                       }
                    }
                '''
        return query

    def test_get_sliders(self):
        result = schema.execute(self.get_sliders_query())
        sliders = result.data.get('sliders', [])
        self.assertEquals(len(sliders), 1)



import os
import io
from setuptools import find_packages, setup

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, 'README.rst')).read()


def get_path(*args):
    return os.path.join(os.path.dirname(__file__), *args)


def read_from(filepath):
    with io.open(filepath, 'rt', encoding='utf8') as f:
        return f.read()


def get_requirements(filename='requirements.txt'):
    data = read_from(get_path(filename))
    lines = map(lambda s: s.strip(), data.splitlines())
    return [l for l in lines if l and not l.startswith('#')]


setup(
    name='crehpages',
    version='0.0.9',
    packages=find_packages(),
    description='Pages application',
    long_description=README,
    author='Jonathan',
    author_email='devops@crehana.com',
    url='https://bitbucket.org/crehana/creh-pages',
    license='MIT',
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
    install_requires=get_requirements(),
    test_suite="runtests.runtests",
    tests_require=[

    ],
)


# -*- coding: utf-8 -*-
import graphene

from graphene import AbstractType

from pages.models.page import Page
from pages.api.page.schema.nodes.page import PageNode


class PageQuery(AbstractType):
    page = graphene.Field(PageNode, id=graphene.Int(), slug=graphene.String())
    pages = graphene.List(PageNode, description='List of pages')

    def resolve_pages(self, args, context, inf):
        return Page.objects.activated()

    def resolve_page(self, args, context, inf):
        page = Page.objects.none()
        if args.get('id', None):
            return Page.objects.activated().get(id=args.get('id', None))
        elif args.get('slug', None):
            page = Page.objects.activated().get(slug=args.get('slug', None))
        return page
